# Configure paths for ADGALI
# Stephane APIOU 24/04/2000
# stolen from Sam Lantinga

dnl AM_PATH_AGDALI([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for AGDALI, and define AGDALI_CFLAGS and AGDALI_LIBS
dnl
AC_DEFUN(AM_PATH_AGDALI,
[dnl 
dnl Get the cflags and libraries from the agdali-config script
dnl
AC_ARG_WITH(agdali-prefix,[  --with-agdali-prefix=PFX   Prefix where AGDALI is installed (optional)],
            agdali_prefix="$withval", agdali_prefix="")
AC_ARG_WITH(agdali-exec-prefix,[  --with-agdali-exec-prefix=PFX Exec prefix where AGDALI is installed (optional)],
            agdali_exec_prefix="$withval", agdali_exec_prefix="")
AC_ARG_ENABLE(agdalitest, [  --disable-agdalitest       Do not try to compile and run a test AGDALI program],
		    , enable_agdalitest=yes)

  if test x$agdali_exec_prefix != x ; then
     agdali_args="$agdali_args --exec-prefix=$agdali_exec_prefix"
     if test x${AGDALI_CONFIG+set} != xset ; then
        AGDALI_CONFIG=$agdali_exec_prefix/bin/agdali-config
     fi
  fi
  if test x$agdali_prefix != x ; then
     agdali_args="$agdali_args --prefix=$agdali_prefix"
     if test x${AGDALI_CONFIG+set} != xset ; then
        AGDALI_CONFIG=$agdali_prefix/bin/agdali-config
     fi
  fi

  AC_PATH_PROG(AGDALI_CONFIG, agdali-config, no)
  min_agdali_version=ifelse([$1], ,0.11.0,$1)
  AC_MSG_CHECKING(for AGDALI - version >= $min_agdali_version)
  no_agdali=""
  if test "$AGDALI_CONFIG" = "no" ; then
    no_agdali=yes
  else
    AGDALI_CFLAGS=`$AGDALI_CONFIG $agdaliconf_args --cflags`
    AGDALI_LIBS=`$AGDALI_CONFIG $agdaliconf_args --libs`

    agdali_major_version=`$AGDALI_CONFIG $agdali_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    agdali_minor_version=`$AGDALI_CONFIG $agdali_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    agdali_micro_version=`$AGDALI_CONFIG $agdali_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
    if test "x$enable_agdalitest" = "xyes" ; then
      ac_save_CFLAGS="$CFLAGS"
      ac_save_LIBS="$LIBS"
      CFLAGS="$CFLAGS $AGDALI_CFLAGS"
      LIBS="$LIBS $AGDALI_LIBS"
dnl
dnl Now check if the installed AGDALI is sufficiently new. (Also sanity
dnl checks the results of agdali-config to some extent
dnl
      rm -f conf.agdalitest
      AC_TRY_RUN([
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "AGDALI.h"

char*
my_strdup (char *str)
{
  char *new_str;
  
  if (str)
    {
      new_str = (char *)malloc ((strlen (str) + 1) * sizeof(char));
      strcpy (new_str, str);
    }
  else
    new_str = NULL;
  
  return new_str;
}

int main (int argc, char *argv[])
{
  int major, minor, micro;
  char *tmp_version;

  /* This hangs on some systems (?)
  system ("touch conf.agdalitest");
  */
  { FILE *fp = fopen("conf.agdalitest", "a"); if ( fp ) fclose(fp); }

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  tmp_version = my_strdup("$min_agdali_version");
  if (sscanf(tmp_version, "%d.%d.%d", &major, &minor, &micro) != 3) {
     printf("%s, bad version string\n", "$min_agdali_version");
     exit(1);
   }

   if (($agdali_major_version > major) ||
      (($agdali_major_version == major) && ($agdali_minor_version > minor)) ||
      (($agdali_major_version == major) && ($agdali_minor_version == minor) && ($agdali_micro_version >= micro)))
    {
      return 0;
    }
  else
    {
      printf("\n*** 'agdali-config --version' returned %d.%d.%d, but the minimum version\n", $agdali_major_version, $agdali_minor_version, $agdali_micro_version);
      printf("*** of AGDALI required is %d.%d.%d. If agdali-config is correct, then it is\n", major, minor, micro);
      printf("*** best to upgrade to the required version.\n");
      printf("*** If agdali-config was wrong, set the environment variable AGDALI_CONFIG\n");
      printf("*** to point to the correct copy of agdali-config, and remove the file\n");
      printf("*** config.cache before re-running configure\n");
      return 1;
    }
}

],, no_agdali=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
     fi
  fi
  if test "x$no_agdali" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])     
  else
     AC_MSG_RESULT(no)
     if test "$AGDALI_CONFIG" = "no" ; then
       echo "*** The agdali-config script installed by AGDALI could not be found"
       echo "*** If AGDALI was installed in PREFIX, make sure PREFIX/bin is in"
       echo "*** your path, or set the AGDALI_CONFIG environment variable to the"
       echo "*** full path to agdali-config."
     else
       if test -f conf.agdalitest ; then
        :
       else
          echo "*** Could not run AGDALI test program, checking why..."
          CFLAGS="$CFLAGS $AGDALI_CFLAGS"
          LIBS="$LIBS $AGDALI_LIBS"
          AC_TRY_LINK([
#include <stdio.h>
#include "agdali.h"
],      [ return 0; ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding AGDALI or finding the wrong"
          echo "*** version of AGDALI. If it is not finding AGDALI, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location  Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"
	  echo "***"
          echo "*** If you have an old version installed, it is best to remove it, although"
          echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"],
        [ echo "*** The test program failed to compile or link. See the file config.log for the"
          echo "*** exact error that occured. This usually means AGDALI was incorrectly installed"
          echo "*** or that you have moved AGDALI since it was installed. In the latter case, you"
          echo "*** may want to edit the agdali-config script: $AGDALI_CONFIG" ])
          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
       fi
     fi
     AGDALI_CFLAGS=""
     AGDALI_LIBS=""
     ifelse([$3], , :, [$3])
  fi
  AC_SUBST(AGDALI_CFLAGS)
  AC_SUBST(AGDALI_LIBS)
  rm -f conf.agdalitest
])
